pub struct Prefixed<A> { /* private fields */ }Expand description
A shape whose names all begin with one word.
What keeps two surfaces’ declarations apart where both are emitted into one place, without either surface stating anything about the other.
Implementations